@@ -237,7 +237,6 @@ static struct apr_thread_list_elt *elt_new(apr_thread_pool_t * me,
  */
 static void *APR_THREAD_FUNC thread_pool_func(apr_thread_t * t, void *param)
 {
-    apr_status_t rv = APR_SUCCESS;
     apr_thread_pool_t *me = param;
     apr_thread_pool_task_t *task = NULL;
     apr_interval_time_t wait;
@@ -313,10 +312,10 @@ static void *APR_THREAD_FUNC thread_pool_func(apr_thread_t * t, void *param)
             wait = -1;
 
         if (wait >= 0) {
-            rv = apr_thread_cond_timedwait(me->cond, me->lock, wait);
+            apr_thread_cond_timedwait(me->cond, me->lock, wait);
         }
         else {
-            rv = apr_thread_cond_wait(me->cond, me->lock);
+            apr_thread_cond_wait(me->cond, me->lock);
         }
     }
 
@@ -329,15 +328,15 @@ static void *APR_THREAD_FUNC thread_pool_func(apr_thread_t * t, void *param)
 
 static apr_status_t thread_pool_cleanup(void *me)
 {
-    apr_thread_pool_t *_self = me;
+    apr_thread_pool_t *_myself = me;
 
-    _self->terminated = 1;
-    apr_thread_pool_idle_max_set(_self, 0);
-    while (_self->thd_cnt) {
+    _myself->terminated = 1;
+    apr_thread_pool_idle_max_set(_myself, 0);
+    while (_myself->thd_cnt) {
         apr_sleep(20 * 1000);   /* spin lock with 20 ms */
     }
-    apr_thread_mutex_destroy(_self->lock);
-    apr_thread_cond_destroy(_self->cond);
+    apr_thread_mutex_destroy(_myself->lock);
+    apr_thread_cond_destroy(_myself->cond);
     return APR_SUCCESS;
 }
 
@@ -353,13 +352,18 @@ APU_DECLARE(apr_status_t) apr_thread_pool_create(apr_thread_pool_t ** me,
     *me = NULL;
     tp = apr_pcalloc(pool, sizeof(apr_thread_pool_t));
 
-    tp->pool = pool;
-
-    rv = thread_pool_construct(tp, init_threads, max_threads);
-    if (APR_SUCCESS != rv) {
+    /*
+     * This pool will be used by different threads. As we cannot ensure that
+     * our caller won't use the pool without acquiring the mutex, we must
+     * create a new sub pool.
+     */
+    rv = apr_pool_create(&tp->pool, pool);
+    if (APR_SUCCESS != rv)
         return rv;
-    }
-    apr_pool_cleanup_register(pool, tp, thread_pool_cleanup,
+    rv = thread_pool_construct(tp, init_threads, max_threads);
+    if (APR_SUCCESS != rv)
+        return rv;
+    apr_pool_cleanup_register(tp->pool, tp, thread_pool_cleanup,
                               apr_pool_cleanup_null);
 
     while (init_threads) {
